"""extensions
Example:
    
    from flask_sqlalchemy import SQLAlchemy
    db = SQLAlchemy()


Usage:

    # in settings
    EXTENSIONS = [
        ...
        'api.extensions.db'
        ...
    ]
"""
